diff --git a/README b/README
index b7d6320856..d848e19810 100644
--- a/README
+++ b/README
@@ -1,7 +1,7 @@
phpMyAdmin - Readme
===================
-Version 3.4.0-beta4-dev
+Version 3.4.0-rc1-dev
A set of PHP-scripts to manage MySQL over the web.
diff --git a/js/sql.js b/js/sql.js
index 9b5edf99d3..1c46c056b1 100644
--- a/js/sql.js
+++ b/js/sql.js
@@ -423,99 +423,77 @@ $(document).ready(function() {
// looping through all columns or rows, to find the required data and then storing it in an array.
var $this_children = $(this).children('span.nowrap').children('a').children('span.nowrap');
- if (disp_mode != 'vertical'){
+ if (disp_mode != 'vertical') {
$this_children.empty();
$this_children.text(PMA_messages['strSave']);
} else {
- // vertical
+ // vertical
data_vt = $this_children.html();
$this_children.text(PMA_messages['strSave']);
}
var hide_link = '
' + PMA_messages['strHide'] + '';
- if (disp_mode != 'vertical'){
+ if (disp_mode != 'vertical') {
$(this).append(hide_link);
- $('#table_results tbody tr td a#hide').click(function(){
+ $('#table_results tbody tr td a#hide').click(function() {
$this_children = $(this).siblings('span.nowrap').children('a').children('span.nowrap');
$this_children.empty();
$this_children.text(PMA_messages['strInlineEdit']);
+
var $this_hide = $(this).parent();
$this_hide.removeClass("inline_edit_active hover").addClass("inline_edit_anchor");
+ $this_hide.parent().removeClass("hover");
+ $this_hide.siblings().removeClass("hover");
+
var last_column = $this_hide.siblings().length;
- var txt = [];
- var blob_index = [];
- var k = 0;
- for(var i = 4; i < last_column; i++){
- if($this_hide.siblings("td:eq(" + i + ")").children('a:eq(0)').length ){
- blob_index[k] = i;
- k++;
+ var txt = '';
+ for(var i = 4; i < last_column; i++) {
+ if($this_hide.siblings("td:eq(" + i + ")").hasClass("inline_edit") == false) {
continue;
}
- txt[i - 4] = $this_hide.siblings("td:eq(" + i + ")").children(' .original_data').html();
- }
- k = 0;
- for (var i = 4; i < last_column; i++){
- if ( blob_index[k] == i){
- k++;
- continue;
- }
- if($this_hide.siblings("td:eq(" + i + ")").children().length !=0){
+ txt = $this_hide.siblings("td:eq(" + i + ")").children(' .original_data').html();
+ if($this_hide.siblings("td:eq(" + i + ")").children().length != 0) {
$this_hide.siblings("td:eq(" + i + ")").empty();
- $this_hide.siblings("td:eq(" + i + ")").append(txt[i-4]);
+ $this_hide.siblings("td:eq(" + i + ")").append(txt);
}
}
$(this).prev().prev().remove();
$(this).prev().remove();
$(this).remove();
- });
+ });
} else {
- var txt=[];
- var rows=$(this).parent().siblings().length;;
+ var txt = '';
+ var rows = $(this).parent().siblings().length;
$(this).append(hide_link);
- $('#table_results tbody tr td a#hide').click(function(){
-
- var pos=$(this).parent().index();
- var $chg_submit=$(this).parent().children('span.nowrap').children('a').children('span.nowrap');
- $chg_submit.empty();
- $chg_submit.append(data_vt);
-
- var $this_row=$(this).parent().parent();
- //alert(pos);
- if(parseInt(pos)%2==0){
- $this_row.siblings("tr:eq(3) td:eq(" + pos + ")").removeClass("odd edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_active").addClass("odd edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_anchor");
+ $('#table_results tbody tr td a#hide').click(function() {
+ var pos = $(this).parent().index();
+ var $chg_submit = $(this).parent().children('span.nowrap').children('a').children('span.nowrap');
+ $chg_submit.empty();
+ $chg_submit.append(data_vt);
- $this_row.siblings("tr:eq(3) td:eq(" + pos + ")").removeClass("odd edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_active hover").addClass("odd edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_anchor");
- } else {
- $this_row.siblings("tr:eq(3) td:eq(" + pos + ")").removeClass("even edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_active").addClass("even edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_anchor");
+ var $this_row = $(this).parent().parent();
+ if(parseInt(pos) % 2 == 0) {
+ $this_row.siblings("tr:eq(3) td:eq(" + pos + ")").removeClass("odd edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_active").addClass("odd edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_anchor");
- $this_row.siblings("tr:eq(3) td:eq(" + pos + ")").removeClass("even edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_active hover").addClass("even edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_anchor");
+ $this_row.siblings("tr:eq(3) td:eq(" + pos + ")").removeClass("odd edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_active hover").addClass("odd edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_anchor");
+ } else {
+ $this_row.siblings("tr:eq(3) td:eq(" + pos + ")").removeClass("even edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_active").addClass("even edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_anchor");
+ $this_row.siblings("tr:eq(3) td:eq(" + pos + ")").removeClass("even edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_active hover").addClass("even edit_row_anchor row_" + pos + " vpointer vmarker inline_edit_anchor");
+ }
+ for( var i = 6; i <= rows + 2; i++){
+ if( $this_row.siblings("tr:eq(" + i + ") td:eq(" + pos + ")").hasClass("inline_edit") == false) {
+ continue;
}
- var blob_index = [];
- var k = 0;
- for( var i = 6; i <= rows + 2; i++){
- if( $this_row.siblings("tr:eq(" + i + ") td:eq(" + pos + ") a:eq(0)").length !=0 ){
- blob_index[k] = i;
- k++;
- continue;
- }
- txt[i - 6] = $this_row.siblings("tr:eq(" + i + ") td:eq("+pos+") span.original_data").html();
- }
- k = 0;
- for (var i = 6; i <= rows + 2; i++){
- if(blob_index[k] == i){
- k++;
- continue;
- }
- $this_row.siblings("tr:eq("+i+") td:eq("+pos+")").empty();
- $this_row.siblings("tr:eq("+i+") td:eq("+pos+")").append(txt[ i - 6]);
- }
- $(this).prev().remove();
- $(this).prev().remove();
- $(this).remove();
-
- });
+ txt = $this_row.siblings("tr:eq(" + i + ") td:eq(" + pos + ") span.original_data").html();
+ $this_row.siblings("tr:eq(" + i + ") td:eq(" + pos + ")").empty();
+ $this_row.siblings("tr:eq(" + i + ") td:eq(" + pos + ")").append(txt);
+ }
+ $(this).prev().remove();
+ $(this).prev().remove();
+ $(this).remove();
+ });
}
// Initialize some variables
@@ -919,7 +897,9 @@ $(document).ready(function() {
}
PMA_ajaxShowMessage(data.message);
- $this_td.removeClass('inline_edit_active').addClass('inline_edit_anchor');
+ $this_td.removeClass('inline_edit_active hover').addClass('inline_edit_anchor');
+ $this_td.parent().removeClass('hover')
+ $this_td.siblings().removeClass('hover');
$input_siblings.each(function() {
// Inline edit post has been successful.
diff --git a/libraries/Config.class.php b/libraries/Config.class.php
index 0ba6d1a0e1..e791e31357 100644
--- a/libraries/Config.class.php
+++ b/libraries/Config.class.php
@@ -96,7 +96,7 @@ class PMA_Config
*/
function checkSystem()
{
- $this->set('PMA_VERSION', '3.4.0-beta4-dev');
+ $this->set('PMA_VERSION', '3.4.0-rc1-dev');
/**
* @deprecated
*/
diff --git a/libraries/kanji-encoding.lib.php b/libraries/kanji-encoding.lib.php
index 1f17ef719c..67c8b1cddf 100644
--- a/libraries/kanji-encoding.lib.php
+++ b/libraries/kanji-encoding.lib.php
@@ -66,7 +66,7 @@ function PMA_change_enc_order() {
* 2002/1/4 by Y.Kawada
*
* @param string the string to convert
- * @param string the destinasion encoding code
+ * @param string the destination encoding code
* @param string set 'kana' convert to JIS-X208-kana
*
* @global string the available encoding codes list
@@ -99,7 +99,7 @@ function PMA_kanji_str_conv($str, $enc, $kana) {
* 2002/1/4 by Y.Kawada
*
* @param string the name of the file to convert
- * @param string the destinasion encoding code
+ * @param string the destination encoding code
* @param string set 'kana' convert to JIS-X208-kana
*
* @return string the name of the converted file
diff --git a/libraries/display_tbl.lib.php b/libraries/display_tbl.lib.php
index d47e94df78..ef9e3978de 100644
--- a/libraries/display_tbl.lib.php
+++ b/libraries/display_tbl.lib.php
@@ -1325,9 +1325,8 @@ function PMA_displayTableBody(&$dt_result, &$is_display, $map, $analyzed_sql) {
// TEXT fields type so we have to ensure it's really a BLOB
$field_flags = PMA_DBI_field_flags($dt_result, $i);
- // reset $class from $inline_edit_class to just 'data'
- // as we can't edit binary data
- $class = 'data';
+ // remove 'inline_edit' from $class as we can't edit binary data.
+ $class = str_replace('inline_edit', '', $class);
if (stristr($field_flags, 'BINARY')) {
if (!isset($row[$i]) || is_null($row[$i])) {
@@ -1366,9 +1365,9 @@ function PMA_displayTableBody(&$dt_result, &$is_display, $map, $analyzed_sql) {
// g e o m e t r y
} elseif ($meta->type == 'geometry') {
$geometry_text = PMA_handle_non_printable_contents('GEOMETRY', (isset($row[$i]) ? $row[$i] : ''), $transform_function, $transform_options, $default_function, $meta);
- // reset $class from $inline_edit_class to 'data'
- // as we can't edit geometry data
- $class = 'data';
+
+ // remove 'inline_edit' from $class as we can't edit geometry data.
+ $class = str_replace('inline_edit', '', $class);
$vertical_display['data'][$row_no][$i] = PMA_buildValueDisplay($class, $condition_field, $geometry_text);
unset($geometry_text);